/*
 * Copyright 2011 Chris de Vreeze
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package eu.cdevreeze.springjdbc

import scala.collection.immutable

/**
 * Typed query argument, used in the Scala `JdbcTemplate`. The type is an integer constant from `java.sql.Types`.
 *
 * @author Chris de Vreeze
 */
final class TypedArg(val argValue: AnyRef, val argType: Int) extends Immutable {

  require(argValue ne null)
}

object TypedArg {

  def apply(argValue: AnyRef, argType: Int): TypedArg = {
    new TypedArg(argValue, argType)
  }
}
